@@ -27,6 +27,10 @@ def create_form(
     title_font_color = "#ffffff",
     title_background_color = "#1e1e1e",
     title_padding = 15,
+    title_padding_top = None,
+    title_padding_right = None,
+    title_padding_bottom = None,
+    title_padding_left = None,
     title_border_width = 0,
     title_border_color = "#ffffff",
     title_border_radius = 0
@@ -40,6 +44,10 @@ def create_form(
         font_color = title_font_color,
         background_color = title_background_color,
         padding = title_padding,
+        padding_top = title_padding_top,
+        padding_right = title_padding_right,
+        padding_bottom = title_padding_bottom,
+        padding_left = title_padding_left,
         border_width = title_border_width,
         border_color = title_border_color,
         border_radius = title_border_radius
@@ -84,6 +92,10 @@ def create_title(
     font_color = "#ffffff",
     background_color = "#1e1e1e",
     padding = 15,
+    padding_top = None,
+    padding_right = None,
+    padding_bottom = None,
+    padding_left = None,
     border_width = 0,
     border_color = "#ffffff",
     border_radius = 0
@@ -99,6 +111,10 @@ def create_title(
         font_weight = "bold",
         background_color = background_color,
         padding = padding,
+        padding_top = padding_top,
+        padding_right = padding_right,
+        padding_bottom = padding_bottom,
+        padding_left = padding_left,
         border_width = border_width,
         border_color = border_color,
         border_radius = border_radius
@@ -114,18 +130,29 @@ def create_label(
         font_weight = "normal",
         background_color = "#1e1e1e",
         padding = 15,
+        padding_top = None,
+        padding_right = None,
+        padding_bottom = None,
+        padding_left = None,
         border_width = 0,
         border_color = "#ffffff",
         border_radius = 0
 ):
     label = QLabel(text)
+    padding_top_value = padding_top if padding_top is not None else padding
+    padding_right_value = padding_right if padding_right is not None else padding
+    padding_bottom_value = padding_bottom if padding_bottom is not None else padding
+    padding_left_value = padding_left if padding_left is not None else padding
     style = f"""
         font-family: {font_family};
         font-size: {font_size}px;
         color: {font_color};
         font-weight: {font_weight};
         background-color: {background_color};
-        padding: {padding}px;
+        padding-top: {padding_top_value}px;
+        padding-right: {padding_right_value}px;
+        padding-bottom: {padding_bottom_value}px;
+        padding-left: {padding_left_value}px;
         border: {border_width}px solid {border_color};
         border-radius: {border_radius}px;
     """
@@ -140,6 +167,10 @@ def create_button(
     font_weight = "bold",
     background_color = "#1e1e1e",
     padding = 15,
+    padding_top = None,
+    padding_right = None,
+    padding_bottom = None,
+    padding_left = None,
     border_width = 2,
     border_color = "#5c5c5c",
     border_radius = 0,
@@ -155,6 +186,10 @@ def create_button(
     disabled_border_color = "#4a4a4a"
 ):
     button = QPushButton(text)
+    padding_top_value = padding_top if padding_top is not None else padding
+    padding_right_value = padding_right if padding_right is not None else padding
+    padding_bottom_value = padding_bottom if padding_bottom is not None else padding
+    padding_left_value = padding_left if padding_left is not None else padding
     style_sheet = f"""
         QPushButton {{
             font-family: {font_family};
@@ -162,7 +197,10 @@ def create_button(
             color: {font_color};
             font-weight: {font_weight};
             background-color: {background_color};
-            padding: {padding}px;
+            padding-top: {padding_top_value}px;
+            padding-right: {padding_right_value}px;
+            padding-bottom: {padding_bottom_value}px;
+            padding-left: {padding_left_value}px;
             border: {border_width}px solid {border_color};
             border-radius: {border_radius}px;
         }}
@@ -191,6 +229,10 @@ def create_text_box(
     font_weight = "normal",
     background_color = "#1e1e1e",
     padding = 15,
+    padding_top = None,
+    padding_right = None,
+    padding_bottom = None,
+    padding_left = None,
     border_width = 2,
     border_color = "#5c5c5c",
     border_radius = 0,
@@ -212,6 +254,10 @@ def create_text_box(
 ):
     text_box = QLineEdit()
     text_box.setPlaceholderText(placeholder_text)
+    padding_top_value = padding_top if padding_top is not None else padding
+    padding_right_value = padding_right if padding_right is not None else padding
+    padding_bottom_value = padding_bottom if padding_bottom is not None else padding
+    padding_left_value = padding_left if padding_left is not None else padding
     style_sheet = f"""
         QLineEdit {{
             font-family: {font_family};
@@ -219,7 +265,10 @@ def create_text_box(
             color: {font_color};
             font-weight: {font_weight};
             background-color: {background_color};
-            padding: {padding}px;
+            padding-top: {padding_top_value}px;
+            padding-right: {padding_right_value}px;
+            padding-bottom: {padding_bottom_value}px;
+            padding-left: {padding_left_value}px;
             border: {border_width}px solid {border_color};
             border-radius: {border_radius}px;
         }}
@@ -294,6 +343,10 @@ def create_combo_box(
     font_color = "#ffffff",
     background_color = "#1e1e1e",
     padding = 15,
+    padding_top = None,
+    padding_right = None,
+    padding_bottom = None,
+    padding_left = None,
     border_width = 2,
     border_color = "#5c5c5c",
     border_radius = 0,
@@ -315,6 +368,11 @@ def create_combo_box(
     combo_box.addItems(items)
     combo_box.setCurrentIndex(-1)
     
+    padding_top_value = padding_top if padding_top is not None else padding
+    padding_right_value = padding_right if padding_right is not None else padding
+    padding_bottom_value = padding_bottom if padding_bottom is not None else padding
+    padding_left_value = padding_left if padding_left is not None else padding
+
     def get_stylesheet(font_color):
         return f"""
             QComboBox {{
@@ -322,7 +380,10 @@ def create_combo_box(
                 font-size: {font_size}px;
                 color: {font_color};
                 background-color: {background_color};
-                padding: {padding}px;
+                padding-top: {padding_top_value}px;
+                padding-right: {padding_right_value}px;
+                padding-bottom: {padding_bottom_value}px;
+                padding-left: {padding_left_value}px;
                 border: {border_width}px solid {border_color};
                 border-radius: {border_radius}px;
             }}
@@ -361,6 +422,10 @@ def create_checkbox(
     font_color = "#ffffff",
     background_color = "#1e1e1e",
     padding = 5,
+    padding_top = None,
+    padding_right = None,
+    padding_bottom = None,
+    padding_left = None,
     indicator_background_color = "#1e1e1e",
     indicator_border_width = 1,
     indicator_border_color = "#5c5c5c",
@@ -380,13 +445,20 @@ def create_checkbox(
     disabled_border_color = "#4a4a4a"
 ):
     check_box = QCheckBox(text)
+    padding_top_value = padding_top if padding_top is not None else padding
+    padding_right_value = padding_right if padding_right is not None else padding
+    padding_bottom_value = padding_bottom if padding_bottom is not None else padding
+    padding_left_value = padding_left if padding_left is not None else padding
     style_sheet = f"""
         QCheckBox {{
             font-family: {font_family};
             font-size: {font_size}px;
             color: {font_color};
             background-color: {background_color};
-            padding: {padding}px;
+            padding-top: {padding_top_value}px;
+            padding-right: {padding_right_value}px;
+            padding-bottom: {padding_bottom_value}px;
+            padding-left: {padding_left_value}px;
         }}
         QCheckBox::indicator {{
             image: none;
@@ -434,6 +506,10 @@ def create_information_message_box(
     label_font_size = 14,
     label_font_color = "#ffffff",
     label_padding = 15,
+    label_padding_top = None,
+    label_padding_right = None,
+    label_padding_bottom = None,
+    label_padding_left = None,
     label_border_width = 0,
     label_border_color = "#ffffff",
     label_border_radius = 0,
@@ -443,6 +519,10 @@ def create_information_message_box(
     button_font_color = "#ffffff",
     button_background_color = "#1e1e1e",
     button_padding = 15,
+    button_padding_top = None,
+    button_padding_right = None,
+    button_padding_bottom = None,
+    button_padding_left = None,
     button_border_width = 2,
     button_border_color = "#5c5c5c",
     button_border_radius = 0,
@@ -481,12 +561,15 @@ def create_information_message_box(
         font_color=  label_font_color,
         background_color = "transparent",
         padding = label_padding,
+        padding_top = label_padding_top,
+        padding_right = label_padding_right,
+        padding_bottom = label_padding_bottom,
+        padding_left = label_padding_left,
         border_width = label_border_width,
         border_color = label_border_color,
         border_radius = label_border_radius
     )
     main_layout.addWidget(text_label)
-
     accept_button = create_button(
         text = button_text,
         font_family = button_font_family,
@@ -494,6 +577,10 @@ def create_information_message_box(
         font_color = button_font_color,
         background_color = button_background_color,
         padding = button_padding,
+        padding_top = button_padding_top,
+        padding_right = button_padding_right,
+        padding_bottom = button_padding_bottom,
+        padding_left = button_padding_left,
         border_width = button_border_width,
         border_color = button_border_color,
         border_radius = button_border_radius,
@@ -528,6 +615,10 @@ def create_confirmation_message_box(
     label_font_size = 14,
     label_font_color = "#ffffff",
     label_padding = 15,
+    label_padding_top = None,
+    label_padding_right = None,
+    label_padding_bottom = None,
+    label_padding_left = None,
     label_border_width = 0,
     label_border_color = "#ffffff",
     label_border_radius = 0,
@@ -536,6 +627,10 @@ def create_confirmation_message_box(
     button_font_color = "#ffffff",
     button_background_color = "#1e1e1e",
     button_padding = 15,
+    button_padding_top = None,
+    button_padding_right = None,
+    button_padding_bottom = None,
+    button_padding_left = None,
     button_border_width = 2,
     button_border_color = "#5c5c5c",
     button_border_radius = 0,
@@ -576,6 +671,10 @@ def create_confirmation_message_box(
         font_color = label_font_color,
         background_color = "transparent",
         padding = label_padding,
+        padding_top = label_padding_top,
+        padding_right = label_padding_right,
+        padding_bottom = label_padding_bottom,
+        padding_left = label_padding_left,
         border_width = label_border_width,
         border_color = label_border_color,
         border_radius = label_border_radius
@@ -591,6 +690,10 @@ def create_confirmation_message_box(
         font_color = button_font_color,
         background_color = button_background_color,
         padding = button_padding,
+        padding_top = button_padding_top,
+        padding_right = button_padding_right,
+        padding_bottom = button_padding_bottom,
+        padding_left = button_padding_left,
         border_width = button_border_width,
         border_color = button_border_color,
         border_radius = button_border_radius,
@@ -614,6 +717,10 @@ def create_confirmation_message_box(
         font_color = button_font_color,
         background_color = button_background_color,
         padding = button_padding,
+        padding_top = button_padding_top,
+        padding_right = button_padding_right,
+        padding_bottom = button_padding_bottom,
+        padding_left = button_padding_left,
         border_width = button_border_width,
         border_color = button_border_color,
         border_radius = button_border_radius,
@@ -652,7 +759,7 @@ def create_list_table(
     header_font_weight = "bold",
     header_background_color = "#1e1e1e",
     header_border_width = 1,
-    header_border_color = "#1e1e1e",
+    header_border_color = "#191919",
     hover_header_background_color = "#333333",
     hover_header_border_width = 3,
     hover_header_border_color = "#777777",
@@ -758,6 +865,10 @@ def confirm_exit(
     label_font_size = 14,
     label_font_color = "#ffffff",
     label_padding = 15,
+    label_padding_top = None,
+    label_padding_right = None,
+    label_padding_bottom = None,
+    label_padding_left = None,
     label_border_width = 0,
     label_border_color = "#ffffff",
     label_border_radius = 0,
@@ -766,6 +877,10 @@ def confirm_exit(
     button_font_color = "#ffffff",
     button_background_color = "#1e1e1e",
     button_padding = 15,
+    button_padding_top = None,
+    button_padding_right = None,
+    button_padding_bottom = None,
+    button_padding_left = None,
     button_border_width = 2,
     button_border_color = "#5c5c5c",
     button_border_radius = 0,
@@ -790,6 +905,10 @@ def confirm_exit(
         label_font_size = label_font_size,
         label_font_color = label_font_color,
         label_padding = label_padding,
+        label_padding_top = label_padding_top,
+        label_padding_right = label_padding_right,
+        label_padding_bottom = label_padding_bottom,
+        label_padding_left = label_padding_left,
         label_border_width = label_border_width,
         label_border_color = label_border_color,
         label_border_radius = label_border_radius,
@@ -798,6 +917,10 @@ def confirm_exit(
         button_font_color = button_font_color,
         button_background_color = button_background_color,
         button_padding = button_padding,
+        button_padding_top = button_padding_top,
+        button_padding_right = button_padding_right,
+        button_padding_bottom = button_padding_bottom,
+        button_padding_left = button_padding_left,
         button_border_width = button_border_width,
         button_border_color = button_border_color,
         button_border_radius = button_border_radius,
@@ -930,7 +1053,13 @@ def format_id(id_string):
     elif len(clean_id) == 7: return f"{clean_id[0:1]}.{clean_id[1:4]}.{clean_id[4:7]}"
     return id_string
 
-def cellphone_number_format(cellphone_number):
+def format_cellphone_number(cellphone_number):
     clean_number = "".join(filter(str.isdigit, cellphone_number))
     if len(clean_number) == 10: return f"{clean_number[0:4]} - {clean_number[4:10]}"
-    return cellphone_number
\ No newline at end of file
+    return cellphone_number
+
+def format_date(date):
+    day = f"{date.day:02d}"
+    month = f"{date.month:02d}"
+    year = f"{date.year:,}".replace(",", ".")
+    return f"{day}/{month}/{year}"
\ No newline at end of file
